package com.allmycode.p03_04_01

import android.app.NotificationChannel
import android.app.NotificationManager
import android.app.PendingIntent
import android.content.Context
import android.content.Intent
import android.os.Build
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.view.View
import android.widget.Toast
import androidx.core.app.NotificationCompat
import androidx.core.app.NotificationManagerCompat
import java.time.Duration

class MainActivity : AppCompatActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        createNotificationChannel(this,
            NotificationManagerCompat.IMPORTANCE_DEFAULT,
            false, getString(R.string.app_name),
            "App Notification Channel")
    }

    fun createNotificationChannel(
        context: Context, importance: Int, showBadge: Boolean,
        name: String, description: String) {

        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.O) {
            Toast.makeText( this,"API Too Old",
                Toast.LENGTH_LONG)
            return
        }

        val channelId = "${context.packageName}-$name"
        val channel = NotificationChannel(channelId, name,
            importance)
        channel.description = description
        channel.setShowBadge(showBadge)

        val notificationManager = context.getSystemService(
            NotificationManager::class.java)
        notificationManager.createNotificationChannel(channel)
    }

    fun onSendNotificationClick(view: View) {
        val name = getString(R.string.app_name)
        val channelId = "${this.packageName}-$name"

        val notificationBuilder = NotificationCompat.Builder(
            this, channelId).apply {
            setSmallIcon(R.drawable.pizza)
            setContentTitle("Your Pizza is Ready")
            setContentText("Get ready to eat a pizza!")
            setStyle(NotificationCompat.BigTextStyle()
                .bigText("Get ready to eat a pizza!"))
            priority = NotificationCompat.PRIORITY_DEFAULT
            setAutoCancel(true)

            val intent = Intent(applicationContext,
                MainActivity::class.java)
            intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK or
                    Intent.FLAG_ACTIVITY_CLEAR_TASK
            val pendingIntent = PendingIntent.getActivity(
                applicationContext, 0, intent, 0)
            setContentIntent(pendingIntent)
        }

        val notificationManager = this.getSystemService(
            NotificationManager::class.java)
        notificationManager.notify(5,
            notificationBuilder.build())
    }
}
