package com.allmycode.p03_04_04

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.view.inputmethod.InputMethodManager
import androidx.room.Room
import kotlinx.android.synthetic.main.activity_main.*

import org.jetbrains.anko.alert
import org.jetbrains.anko.doAsync
import org.jetbrains.anko.noButton
import org.jetbrains.anko.yesButton


private val DATABASE_NAME = "movies_db"

class MainActivity : AppCompatActivity() {

    lateinit private var movieDatabase: MovieDatabase

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        movieDatabase =
            Room.databaseBuilder(this, MovieDatabase::class.java, DATABASE_NAME)
                .fallbackToDestructiveMigration().build()


        button.setOnClickListener {
            val movie = Movie()
            try {
                movie.movieId = editText.getText().toString().toInt()
            } catch (n: NumberFormatException) {
            }
            movie.movieName = editText2.getText().toString()

            doAsync {
                when (radioGroup.checkedRadioButtonId) {
                    R.id.insert -> {
                        try {
                            movieDatabase.daoAccess().insertOnlySingleMovie(movie)
                        } catch (e: Exception) {
                            alert("Something went wrong.", "Oops!") {
                                yesButton { }
                                noButton { }
                            }
                        }
                        textView.setText("${movie.movieName} Inserted")
                    }
                    R.id.search -> {
                        val movie = movieDatabase.daoAccess().fetchOneMoviesbyMovieId(movie.movieId)
                        textView.setText(movie?.movieName ?: "Not found")
                    }
                    R.id.selectAll -> {
                        val allMovies = movieDatabase.daoAccess().fetchAllMovies()
                        var string = ""

                        for (movie in allMovies) {
                            string += "${movie.movieId} : ${movie.movieName}\n"
                        }
                        textView.setText(string)
                    }
                    R.id.delete -> {
                        val movie = movieDatabase.daoAccess().fetchOneMoviesbyMovieId(movie.movieId)
                        val name = movie.movieName
                        movieDatabase.daoAccess().deleteMovie(movie)
                        textView.setText("$name Deleted")
                    }
                }
            }

            val imm = getSystemService(INPUT_METHOD_SERVICE) as InputMethodManager
            imm.hideSoftInputFromWindow(editText.getWindowToken(), 0)
            imm.hideSoftInputFromWindow(editText2.getWindowToken(), 0)
        }
    }
}
